==> file_maintenance-6.x-1.0.tar.gz: file_maintenance/js/file-maintenance.js <==
// Setup
Drupal.FileMaintenance = Drupal.FileMaintenance || {};
Drupal.FileMaintenance.opendiv = '';
Drupal.FileMaintenance.action = '';
Drupal.FileMaintenance.active = '';

/**
 * Show / hide directory form bulk actions.
 */
Drupal.behaviors.filemaintenance = function() {

  // Expand on error
  if (typeof Drupal.settings.fileMaintenance !== 'undefined') {
    if (Drupal.settings.fileMaintenance.errorfield != '') {
      $('#' + Drupal.settings.fileMaintenance.errorfield).show('fast');
      $('#' + Drupal.settings.fileMaintenance.activelink).addClass('active');
      Drupal.FileMaintenance.active = Drupal.settings.fileMaintenance.errorfield;
    }
  }
  $('.dirlink').each(function() {
      $(this).click(function(e) {
        action = $(this).attr('rel');
        content = $(this).parent().parent().find('.container-inline');

        // Hide 'old' open content.
        if (Drupal.FileMaintenance.opendiv != '' && Drupal.FileMaintenance.opendiv != content.attr('id')) {
          $('#' + Drupal.FileMaintenance.opendiv).hide();
          $('#' + Drupal.FileMaintenance.opendiv).find('input:first').val('');
          Drupal.FileMaintenance.opendiv = '';
          Drupal.FileMaintenance.action = '';
          Drupal.FileMaintenance.active.removeClass('active');
        }
        if (Drupal.FileMaintenance.action == '' || Drupal.FileMaintenance.action == action) {
          // Toggle content.
          if (content.is(':visible')) {
            content.hide();
          }
          else {
            content.show();
          }
        }
        else {
          Drupal.FileMaintenance.active.removeClass('active');
        }

        // Mark link as active.
        if ($(this).hasClass('active')) {
          $(this).removeClass('active');
          content.find('input:first').val('');
        }
        else {
          $(this).addClass('active');
          content.find('input:first').val(action);
        }

        // Store the opened div & clicked action.
        Drupal.FileMaintenance.opendiv = content.attr('id');
        Drupal.FileMaintenance.action = action;
        Drupal.FileMaintenance.active = $(this);
        // Set field description.
        Drupal.behaviors.filemaintenance.description(action, content);

        // Don't follow href.
        e.preventDefault();
      });
  });
}

Drupal.behaviors.filemaintenance.description = function(action, field) {
  var msg = '';

  switch(action) {
    case 'move':
      msg = Drupal.t('Enter destination directory.');
      break;
    case 'delete':
      field.find('input[type=text]').hide();
      break;
    case 'prefix':
      msg = Drupal.t('Enter prefix.');
      break;
    case 'suffix':
      msg = Drupal.t('Enter suffix. The suffix is inserted before the file extension!');
      break;
  }

  if (action != 'delete') {
    field.find('input[type=text]').show();
  }

  field.find('.description').html(msg);
}

==> file_maintenance-6.x-1.1.tar.gz: file_maintenance/js/file-maintenance.js <==
// Setup
Drupal.FileMaintenance = Drupal.FileMaintenance || {};
Drupal.FileMaintenance.opendiv = '';
Drupal.FileMaintenance.action = '';
Drupal.FileMaintenance.active = '';

/**
 * Show / hide directory form bulk actions.
 */
Drupal.behaviors.filemaintenance = function() {

  // Expand on error
  if (typeof Drupal.settings.fileMaintenance !== 'undefined') {
    if (Drupal.settings.fileMaintenance.errorfield != '') {
      $('#' + Drupal.settings.fileMaintenance.errorfield).show('fast');
      $('#' + Drupal.settings.fileMaintenance.activelink).addClass('active');
      Drupal.FileMaintenance.active = Drupal.settings.fileMaintenance.errorfield;
    }
  }
  $('.dirlink').each(function() {
      $(this).click(function(e) {
        action = $(this).attr('rel');
        content = $(this).parent().parent().find('.container-inline');

        // Hide 'old' open content.
        if (Drupal.FileMaintenance.opendiv != '' && Drupal.FileMaintenance.opendiv != content.attr('id')) {
          $('#' + Drupal.FileMaintenance.opendiv).hide();
          $('#' + Drupal.FileMaintenance.opendiv).find('input:first').val('');
          Drupal.FileMaintenance.opendiv = '';
          Drupal.FileMaintenance.action = '';
          Drupal.FileMaintenance.active.removeClass('active');
        }
        if (Drupal.FileMaintenance.action == '' || Drupal.FileMaintenance.action == action) {
          // Toggle content.
          if (content.is(':visible')) {
            content.hide();
          }
          else {
            content.show();
          }
        }
        else {
          Drupal.FileMaintenance.active.removeClass('active');
        }

        // Mark link as active.
        if ($(this).hasClass('active')) {
          $(this).removeClass('active');
          content.find('input:first').val('');
        }
        else {
          $(this).addClass('active');
          content.find('input:first').val(action);
        }

        // Store the opened div & clicked action.
        Drupal.FileMaintenance.opendiv = content.attr('id');
        Drupal.FileMaintenance.action = action;
        Drupal.FileMaintenance.active = $(this);
        // Set field description.
        Drupal.behaviors.filemaintenance.description(action, content);

        // Don't follow href.
        e.preventDefault();
      });
  });
}

Drupal.behaviors.filemaintenance.description = function(action, field) {
  var msg = '';

  switch(action) {
    case 'move':
      msg = Drupal.t('Enter destination directory,<br />starting from the docroot.');
      break;
    case 'delete':
      field.find('input[type=text]').hide();
      break;
    case 'prefix':
      msg = Drupal.t('Enter prefix.');
      break;
    case 'suffix':
      msg = Drupal.t('Enter suffix. The suffix is inserted before the file extension!');
      break;
  }

  if (action != 'delete') {
    field.find('input[type=text]').show();
  }

  field.find('.description').html(msg);
}
